@@ -291,9 +291,9 @@ static void EvalH(Operand *op)
       s = &globTab[s->index];
     }
     db = s->value.db; /* correctness checked below */
-    if (s->ops != &dataBlockSym || ((oper = db->ops) != &functionOps &&
-				    oper != &builtinOps &&
-				    oper != &auto_ops)) {
+    if (s->ops != &dataBlockSym || db == NULL
+        || ((oper = db->ops) != &functionOps &&
+            oper != &builtinOps && oper != &auto_ops)) {
       YError("non-function eval method");
     }
 
@@ -315,9 +315,9 @@ static void EvalH(Operand *op)
 	stack[i].ops = &intScalar; /* set safe OpTable */
 	stack[i + 1].value = stack[i].value;
 	stack[i + 1].index = stack[i].index;
-	stack[i + 1].ops = ops; /* set true OpTable *after* proper initialization */
+	stack[i + 1].ops = ops; /* set true OpTable *after* initialization */
       }
-      stack->value.db = Ref(db);
+      stack->value.db = RefNC(db); /* we already know that db != NULL */
       stack->ops = &dataBlockSym;
     }
     /*** CRITICAL CODE END ***/
@@ -790,8 +790,8 @@ static void get_member(Symbol *owner, h_table_t *table, const char *name)
     owner->value.db = RefNC(&nilDB);
     ops = &dataBlockSym;
   }
-  Unref(old);
   owner->ops = ops;            /* change ops only AFTER value updated */
+  Unref(old);
 }
 
 /* get args from the top of the stack: first arg is hash table, second arg
