@@ -27,8 +27,11 @@
  *-----------------------------------------------------------------------------
  *
  * History:
- *	$Id: yeti_fftw.c,v 1.6 2006/07/19 15:12:55 eric Exp $
+ *	$Id: yeti_fftw.c,v 1.7 2010/07/04 06:27:18 eric Exp $
  *	$Log: yeti_fftw.c,v $
+ *	Revision 1.7  2010/07/04 06:27:18  eric
+ *	Macro OFFSET_OF fixed.
+ *
  *	Revision 1.6  2006/07/19 15:12:55  eric
  *	 - Copyright notice updated.
  *
@@ -82,8 +85,7 @@ extern BuiltIn Y_fftw, Y_fftw_plan;
 #endif
 
 /* Offset (in bytes) of MEMBER in structure TYPE. */
-#define OFFSET_OF(type, member) ((unsigned int) &((type *)0)->member)
-
+#define OFFSET_OF(type, member)    ((char *)&((type *)0)->member - (char *)0)
 
 /* PRIVATE ROUTINES */
 static int get_boolean(Symbol *s);
